<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\ApprovedJobs;


class ApprovedJobsAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, ApprovedJobs $approved_jobs, array $request = [])
    {
        $this->model = $approved_jobs;

        $function = Str::camel($action);
        event('assetise.asset.approved_jobs.action.' . $action . 'ing', [$approved_jobs]);
        $data =  $this->$function($approved_jobs, $request);
        event('assetise.asset.approved_jobs.action.' . $action . 'ed', [$approved_jobs]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(ApprovedJobs $approved_jobs, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $approved_jobs = $approved_jobs->create($attributes);
        return $approved_jobs;
    }

    public function update(ApprovedJobs $approved_jobs, array $request)
    {
        $attributes = $request;
        $approved_jobs->update($attributes);
        return $approved_jobs;
    }

    public function destroy(ApprovedJobs $approved_jobs, array $request)
    {
        $approved_jobs->delete();
        return $approved_jobs;
    }

    public function copy(ApprovedJobs $approved_jobs, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $approved_jobs = $approved_jobs->replicate();
            $approved_jobs->created_at = Carbon::now();
            $approved_jobs->save();
            return $approved_jobs;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $approved_jobs->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $approved_jobs;
    }


}
