<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Asset;


class AssetAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Asset $asset, array $request = [])
    {
        $this->model = $asset;

        $function = Str::camel($action);
        event('assetise.asset.asset.action.' . $action . 'ing', [$asset]);
        $data =  $this->$function($asset, $request);
        event('assetise.asset.asset.action.' . $action . 'ed', [$asset]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Asset $asset, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $asset = $asset->create($attributes);
        return $asset;
    }

    public function update(Asset $asset, array $request)
    {
        $attributes = $request;
        $asset->update($attributes);
        return $asset;
    }

    public function destroy(Asset $asset, array $request)
    {
        $asset->delete();
        return $asset;
    }

    public function copy(Asset $asset, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $asset = $asset->replicate();
            $asset->created_at = Carbon::now();
            $asset->save();
            return $asset;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $asset->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $asset;
    }


}
