<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\AssetClassification;


class AssetClassificationAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, AssetClassification $asset_classification, array $request = [])
    {
        $this->model = $asset_classification;

        $function = Str::camel($action);
        event('assetise.asset.asset_classification.action.' . $action . 'ing', [$asset_classification]);
        $data =  $this->$function($asset_classification, $request);
        event('assetise.asset.asset_classification.action.' . $action . 'ed', [$asset_classification]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(AssetClassification $asset_classification, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $asset_classification = $asset_classification->create($attributes);
        return $asset_classification;
    }

    public function update(AssetClassification $asset_classification, array $request)
    {
        $attributes = $request;
        $asset_classification->update($attributes);
        return $asset_classification;
    }

    public function destroy(AssetClassification $asset_classification, array $request)
    {
        $asset_classification->delete();
        return $asset_classification;
    }

    public function copy(AssetClassification $asset_classification, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $asset_classification = $asset_classification->replicate();
            $asset_classification->created_at = Carbon::now();
            $asset_classification->save();
            return $asset_classification;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $asset_classification->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $asset_classification;
    }


}
