<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Str;
use Assetise\Asset\Models\AssetClassification;
use Assetise\Asset\Scopes\AssetClassificationResourceScope;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Database\RequestScope;

class AssetClassificationActions
{
    use AsAction;
    use LogsActions;
    
    private $model;

    public function handle(string $action, array $request)
    {
        $this->model = app(AssetClassification::class);

        $function = Str::camel($action);

        event('assetise.asset.asset_classification.action.' . $action . 'ing', [$request]);
        $data = $this->$function($request);
        event('assetise.asset.asset_classification.action.' . $action . 'ed', [$data]);

        $this->logsAction();
        return $data;

    }

    public function paginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $asset_classification = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new AssetClassificationResourceScope())
            ->paginate($pageLimit);

        return $asset_classification;
    }

    public function simplePaginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $asset_classification = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new AssetClassificationResourceScope())
            ->simplePaginate($pageLimit);

        return $asset_classification;
    }

    function empty(array $request) {
        return $this->model->forceDelete();
    }

    function restore(array $request) {
        return $this->model->restore();
    }

    public function delete(array $request)
    {
        $ids = $request['ids'];
        $ids = collect($ids)->map(function ($id) {
            return hashids_decode($id);
        });
        return $this->model->whereIn('id', $ids)->delete();
    }
}
