<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\AssetType;


class AssetTypeAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, AssetType $asset_type, array $request = [])
    {
        $this->model = $asset_type;

        $function = Str::camel($action);
        event('assetise.asset.asset_type.action.' . $action . 'ing', [$asset_type]);
        $data =  $this->$function($asset_type, $request);
        event('assetise.asset.asset_type.action.' . $action . 'ed', [$asset_type]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(AssetType $asset_type, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $asset_type = $asset_type->create($attributes);
        return $asset_type;
    }

    public function update(AssetType $asset_type, array $request)
    {
        $attributes = $request;
        $asset_type->update($attributes);
        return $asset_type;
    }

    public function destroy(AssetType $asset_type, array $request)
    {
        $asset_type->delete();
        return $asset_type;
    }

    public function copy(AssetType $asset_type, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $asset_type = $asset_type->replicate();
            $asset_type->created_at = Carbon::now();
            $asset_type->save();
            return $asset_type;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $asset_type->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $asset_type;
    }


}
