<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Condition;


class ConditionAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Condition $condition, array $request = [])
    {
        $this->model = $condition;

        $function = Str::camel($action);
        event('assetise.asset.condition.action.' . $action . 'ing', [$condition]);
        $data =  $this->$function($condition, $request);
        event('assetise.asset.condition.action.' . $action . 'ed', [$condition]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Condition $condition, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $condition = $condition->create($attributes);
        return $condition;
    }

    public function update(Condition $condition, array $request)
    {
        $attributes = $request;
        $condition->update($attributes);
        return $condition;
    }

    public function destroy(Condition $condition, array $request)
    {
        $condition->delete();
        return $condition;
    }

    public function copy(Condition $condition, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $condition = $condition->replicate();
            $condition->created_at = Carbon::now();
            $condition->save();
            return $condition;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $condition->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $condition;
    }


}
