<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Consequence;


class ConsequenceAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Consequence $consequence, array $request = [])
    {
        $this->model = $consequence;

        $function = Str::camel($action);
        event('assetise.asset.consequence.action.' . $action . 'ing', [$consequence]);
        $data =  $this->$function($consequence, $request);
        event('assetise.asset.consequence.action.' . $action . 'ed', [$consequence]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Consequence $consequence, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $consequence = $consequence->create($attributes);
        return $consequence;
    }

    public function update(Consequence $consequence, array $request)
    {
        $attributes = $request;
        $consequence->update($attributes);
        return $consequence;
    }

    public function destroy(Consequence $consequence, array $request)
    {
        $consequence->delete();
        return $consequence;
    }

    public function copy(Consequence $consequence, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $consequence = $consequence->replicate();
            $consequence->created_at = Carbon::now();
            $consequence->save();
            return $consequence;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $consequence->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $consequence;
    }


}
