<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Expenditure;


class ExpenditureAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Expenditure $expenditure, array $request = [])
    {
        $this->model = $expenditure;

        $function = Str::camel($action);
        event('assetise.asset.expenditure.action.' . $action . 'ing', [$expenditure]);
        $data =  $this->$function($expenditure, $request);
        event('assetise.asset.expenditure.action.' . $action . 'ed', [$expenditure]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Expenditure $expenditure, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $expenditure = $expenditure->create($attributes);
        return $expenditure;
    }

    public function update(Expenditure $expenditure, array $request)
    {
        $attributes = $request;
        $expenditure->update($attributes);
        return $expenditure;
    }

    public function destroy(Expenditure $expenditure, array $request)
    {
        $expenditure->delete();
        return $expenditure;
    }

    public function copy(Expenditure $expenditure, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $expenditure = $expenditure->replicate();
            $expenditure->created_at = Carbon::now();
            $expenditure->save();
            return $expenditure;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $expenditure->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $expenditure;
    }


}
