<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Inspection;


class InspectionAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Inspection $inspection, array $request = [])
    {
        $this->model = $inspection;

        $function = Str::camel($action);
        event('assetise.asset.inspection.action.' . $action . 'ing', [$inspection]);
        $data =  $this->$function($inspection, $request);
        event('assetise.asset.inspection.action.' . $action . 'ed', [$inspection]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Inspection $inspection, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $inspection = $inspection->create($attributes);
        return $inspection;
    }

    public function update(Inspection $inspection, array $request)
    {
        $attributes = $request;
        $inspection->update($attributes);
        return $inspection;
    }

    public function destroy(Inspection $inspection, array $request)
    {
        $inspection->delete();
        return $inspection;
    }

    public function copy(Inspection $inspection, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $inspection = $inspection->replicate();
            $inspection->created_at = Carbon::now();
            $inspection->save();
            return $inspection;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $inspection->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $inspection;
    }


}
