<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Lcc;


class LccAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Lcc $lcc, array $request = [])
    {
        $this->model = $lcc;

        $function = Str::camel($action);
        event('assetise.asset.lcc.action.' . $action . 'ing', [$lcc]);
        $data =  $this->$function($lcc, $request);
        event('assetise.asset.lcc.action.' . $action . 'ed', [$lcc]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Lcc $lcc, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $lcc = $lcc->create($attributes);
        return $lcc;
    }

    public function update(Lcc $lcc, array $request)
    {
        $attributes = $request;
        $lcc->update($attributes);
        return $lcc;
    }

    public function destroy(Lcc $lcc, array $request)
    {
        $lcc->delete();
        return $lcc;
    }

    public function copy(Lcc $lcc, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $lcc = $lcc->replicate();
            $lcc->created_at = Carbon::now();
            $lcc->save();
            return $lcc;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $lcc->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $lcc;
    }


}
