<?php

namespace Assetise\Asset\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Assetise\Asset\Models\Proposal;


class ProposalAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Proposal $proposal, array $request = [])
    {
        $this->model = $proposal;

        $function = Str::camel($action);
        event('assetise.asset.proposal.action.' . $action . 'ing', [$proposal]);
        $data =  $this->$function($proposal, $request);
        event('assetise.asset.proposal.action.' . $action . 'ed', [$proposal]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Proposal $proposal, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $proposal = $proposal->create($attributes);
        return $proposal;
    }

    public function update(Proposal $proposal, array $request)
    {
        $attributes = $request;
        $proposal->update($attributes);
        return $proposal;
    }

    public function destroy(Proposal $proposal, array $request)
    {
        $proposal->delete();
        return $proposal;
    }

    public function copy(Proposal $proposal, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $proposal = $proposal->replicate();
            $proposal->created_at = Carbon::now();
            $proposal->save();
            return $proposal;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $proposal->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $proposal;
    }


}
