<?php

namespace Assetise\Asset\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Assetise\Asset\Forms\AssetClassification as AssetClassificationForm;
use Assetise\Asset\Http\Requests\AssetClassificationResourceRequest;
use Assetise\Asset\Http\Resources\AssetClassificationResource;
use Assetise\Asset\Http\Resources\AssetClassificationsCollection;
use Assetise\Asset\Models\AssetClassification;
use Assetise\Asset\Actions\AssetClassificationAction;
use Assetise\Asset\Actions\AssetClassificationActions;


/**
 * Resource controller class for asset_classification.
 */
class AssetClassificationResourceController extends BaseController
{

    /**
     * Initialize asset_classification resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = AssetClassificationForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('assetise.asset.modules'), 'asset', guard_url('asset'));
    }

    /**
     * Display a list of asset_classification.
     *
     * @return Response
     */
    public function index(AssetClassificationResourceRequest $request)
    {
        $request = $request->all();
        $page = AssetClassificationActions::run('paginate', $request);

        $data = new AssetClassificationsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('asset::asset_classification.names'))
            ->view('asset::asset_classification.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display asset_classification.
     *
     * @param Request $request
     * @param Model   $asset_classification
     *
     * @return Response
     */
    public function show(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetClassificationResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('asset::asset_classification.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('asset::asset_classification.show')
            ->output();
    }

    /**
     * Show the form for creating a new asset_classification.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetClassificationResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('asset::asset_classification.name'))
            ->view('asset::asset_classification.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new asset_classification.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        try {
            $request = $request->all();
            $model = AssetClassificationAction::run('store', $model, $request);
            $data = new AssetClassificationResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('asset::asset_classification.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('asset/asset_classification/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/asset/asset_classification'))
                ->redirect();
        }

    }

    /**
     * Show asset_classification for editing.
     *
     * @param Request $request
     * @param Model   $asset_classification
     *
     * @return Response
     */
    public function edit(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetClassificationResource($model);
        // return view('asset::asset_classification.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('asset::asset_classification.name'))
            ->view('asset::asset_classification.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the asset_classification.
     *
     * @param Request $request
     * @param Model   $asset_classification
     *
     * @return Response
     */
    public function update(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        try {
            $request = $request->all();
            $model = AssetClassificationAction::run('update', $model, $request);
            $data = new AssetClassificationResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('asset::asset_classification.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/asset_classification/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/asset_classification/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the asset_classification.
     *
     * @param Model   $asset_classification
     *
     * @return Response
     */
    public function destroy(AssetClassificationResourceRequest $request, AssetClassification $model)
    {
        try {

            $request = $request->all();
            $model = AssetClassificationAction::run('destroy', $model, $request);
            $data = new AssetClassificationResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('asset::asset_classification.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/asset_classification/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/asset_classification/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
