<?php

namespace Assetise\Asset\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Assetise\Asset\Forms\AssetLevel as AssetLevelForm;
use Assetise\Asset\Http\Requests\AssetLevelResourceRequest;
use Assetise\Asset\Http\Resources\AssetLevelResource;
use Assetise\Asset\Http\Resources\AssetLevelsCollection;
use Assetise\Asset\Models\AssetLevel;
use Assetise\Asset\Actions\AssetLevelAction;
use Assetise\Asset\Actions\AssetLevelActions;


/**
 * Resource controller class for asset_level.
 */
class AssetLevelResourceController extends BaseController
{

    /**
     * Initialize asset_level resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = AssetLevelForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('assetise.asset.modules'), 'asset', guard_url('asset'));
    }

    /**
     * Display a list of asset_level.
     *
     * @return Response
     */
    public function index(AssetLevelResourceRequest $request)
    {
        $request = $request->all();
        $page = AssetLevelActions::run('paginate', $request);

        $data = new AssetLevelsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('asset::asset_level.names'))
            ->view('asset::asset_level.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display asset_level.
     *
     * @param Request $request
     * @param Model   $asset_level
     *
     * @return Response
     */
    public function show(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetLevelResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('asset::asset_level.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('asset::asset_level.show')
            ->output();
    }

    /**
     * Show the form for creating a new asset_level.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetLevelResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('asset::asset_level.name'))
            ->view('asset::asset_level.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new asset_level.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        try {
            $request = $request->all();
            $model = AssetLevelAction::run('store', $model, $request);
            $data = new AssetLevelResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('asset::asset_level.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('asset/asset_level/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/asset/asset_level'))
                ->redirect();
        }

    }

    /**
     * Show asset_level for editing.
     *
     * @param Request $request
     * @param Model   $asset_level
     *
     * @return Response
     */
    public function edit(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AssetLevelResource($model);
        // return view('asset::asset_level.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('asset::asset_level.name'))
            ->view('asset::asset_level.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the asset_level.
     *
     * @param Request $request
     * @param Model   $asset_level
     *
     * @return Response
     */
    public function update(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        try {
            $request = $request->all();
            $model = AssetLevelAction::run('update', $model, $request);
            $data = new AssetLevelResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('asset::asset_level.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/asset_level/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/asset_level/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the asset_level.
     *
     * @param Model   $asset_level
     *
     * @return Response
     */
    public function destroy(AssetLevelResourceRequest $request, AssetLevel $model)
    {
        try {

            $request = $request->all();
            $model = AssetLevelAction::run('destroy', $model, $request);
            $data = new AssetLevelResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('asset::asset_level.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/asset_level/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/asset_level/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
