<?php

namespace Assetise\Asset\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Assetise\Asset\Forms\Lcc as LccForm;
use Assetise\Asset\Http\Requests\LccResourceRequest;
use Assetise\Asset\Http\Resources\LccResource;
use Assetise\Asset\Http\Resources\LccsCollection;
use Assetise\Asset\Models\Lcc;
use Assetise\Asset\Actions\LccAction;
use Assetise\Asset\Actions\LccActions;


/**
 * Resource controller class for lcc.
 */
class LccResourceController extends BaseController
{

    /**
     * Initialize lcc resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = LccForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('assetise.asset.modules'), 'asset', guard_url('asset'));
    }

    /**
     * Display a list of lcc.
     *
     * @return Response
     */
    public function index(LccResourceRequest $request)
    {
        $request = $request->all();
        $page = LccActions::run('paginate', $request);

        $data = new LccsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('asset::lcc.names'))
            ->view('asset::lcc.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display lcc.
     *
     * @param Request $request
     * @param Model   $lcc
     *
     * @return Response
     */
    public function show(LccResourceRequest $request, Lcc $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LccResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('asset::lcc.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('asset::lcc.show')
            ->output();
    }

    /**
     * Show the form for creating a new lcc.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LccResourceRequest $request, Lcc $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LccResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('asset::lcc.name'))
            ->view('asset::lcc.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new lcc.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LccResourceRequest $request, Lcc $model)
    {
        try {
            $request = $request->all();
            $model = LccAction::run('store', $model, $request);
            $data = new LccResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('asset::lcc.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('asset/lcc/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/asset/lcc'))
                ->redirect();
        }

    }

    /**
     * Show lcc for editing.
     *
     * @param Request $request
     * @param Model   $lcc
     *
     * @return Response
     */
    public function edit(LccResourceRequest $request, Lcc $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LccResource($model);
        // return view('asset::lcc.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('asset::lcc.name'))
            ->view('asset::lcc.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the lcc.
     *
     * @param Request $request
     * @param Model   $lcc
     *
     * @return Response
     */
    public function update(LccResourceRequest $request, Lcc $model)
    {
        try {
            $request = $request->all();
            $model = LccAction::run('update', $model, $request);
            $data = new LccResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('asset::lcc.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/lcc/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/lcc/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the lcc.
     *
     * @param Model   $lcc
     *
     * @return Response
     */
    public function destroy(LccResourceRequest $request, Lcc $model)
    {
        try {

            $request = $request->all();
            $model = LccAction::run('destroy', $model, $request);
            $data = new LccResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('asset::lcc.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('asset/lcc/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/lcc/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
