<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\AssetClassification;

class AssetClassificationPolicy
{


    /**
     * Determine if the given user can view the asset_classification.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetClassification $asset_classification
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AssetClassification $asset_classification)
    {
        if ($authUser->canDo('asset.asset_classification.view') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_classification->user_id == user_id() && $asset_classification->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_classification.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.asset_classification.create');
    }

    /**
     * Determine if the given user can update the given asset_classification.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetClassification $asset_classification
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AssetClassification $asset_classification)
    {
        if ($authUser->canDo('asset.asset_classification.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_classification->user_id == user_id() && $asset_classification->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_classification.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AssetClassification $asset_classification)
    {
        return $asset_classification->user_id == user_id() && $asset_classification->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_classification.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AssetClassification $asset_classification)
    {
        if ($authUser->canDo('asset.asset_classification.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_classification.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AssetClassification $asset_classification)
    {
        if ($authUser->canDo('asset.asset_classification.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
