<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\AssetLevel;

class AssetLevelPolicy
{


    /**
     * Determine if the given user can view the asset_level.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetLevel $asset_level
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AssetLevel $asset_level)
    {
        if ($authUser->canDo('asset.asset_level.view') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_level->user_id == user_id() && $asset_level->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_level.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.asset_level.create');
    }

    /**
     * Determine if the given user can update the given asset_level.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetLevel $asset_level
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AssetLevel $asset_level)
    {
        if ($authUser->canDo('asset.asset_level.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_level->user_id == user_id() && $asset_level->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_level.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AssetLevel $asset_level)
    {
        return $asset_level->user_id == user_id() && $asset_level->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_level.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AssetLevel $asset_level)
    {
        if ($authUser->canDo('asset.asset_level.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_level.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AssetLevel $asset_level)
    {
        if ($authUser->canDo('asset.asset_level.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
