<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\AssetLocation;

class AssetLocationPolicy
{


    /**
     * Determine if the given user can view the asset_location.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetLocation $asset_location
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AssetLocation $asset_location)
    {
        if ($authUser->canDo('asset.asset_location.view') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_location->user_id == user_id() && $asset_location->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.asset_location.create');
    }

    /**
     * Determine if the given user can update the given asset_location.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetLocation $asset_location
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AssetLocation $asset_location)
    {
        if ($authUser->canDo('asset.asset_location.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_location->user_id == user_id() && $asset_location->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AssetLocation $asset_location)
    {
        return $asset_location->user_id == user_id() && $asset_location->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AssetLocation $asset_location)
    {
        if ($authUser->canDo('asset.asset_location.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AssetLocation $asset_location)
    {
        if ($authUser->canDo('asset.asset_location.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
