<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\Asset;

class AssetPolicy
{


    /**
     * Determine if the given user can view the asset.
     *
     * @param UserPolicyInterface $authUser
     * @param Asset $asset
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Asset $asset)
    {
        if ($authUser->canDo('asset.asset.view') && $authUser->isAdmin()) {
            return true;
        }

        return $asset->user_id == user_id() && $asset->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.asset.create');
    }

    /**
     * Determine if the given user can update the given asset.
     *
     * @param UserPolicyInterface $authUser
     * @param Asset $asset
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Asset $asset)
    {
        if ($authUser->canDo('asset.asset.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $asset->user_id == user_id() && $asset->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Asset $asset)
    {
        return $asset->user_id == user_id() && $asset->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Asset $asset)
    {
        if ($authUser->canDo('asset.asset.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Asset $asset)
    {
        if ($authUser->canDo('asset.asset.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
