<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\AssetType;

class AssetTypePolicy
{


    /**
     * Determine if the given user can view the asset_type.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetType $asset_type
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AssetType $asset_type)
    {
        if ($authUser->canDo('asset.asset_type.view') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_type->user_id == user_id() && $asset_type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.asset_type.create');
    }

    /**
     * Determine if the given user can update the given asset_type.
     *
     * @param UserPolicyInterface $authUser
     * @param AssetType $asset_type
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AssetType $asset_type)
    {
        if ($authUser->canDo('asset.asset_type.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $asset_type->user_id == user_id() && $asset_type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AssetType $asset_type)
    {
        return $asset_type->user_id == user_id() && $asset_type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AssetType $asset_type)
    {
        if ($authUser->canDo('asset.asset_type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AssetType $asset_type)
    {
        if ($authUser->canDo('asset.asset_type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
