<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\Condition;

class ConditionPolicy
{


    /**
     * Determine if the given user can view the condition.
     *
     * @param UserPolicyInterface $authUser
     * @param Condition $condition
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Condition $condition)
    {
        if ($authUser->canDo('asset.condition.view') && $authUser->isAdmin()) {
            return true;
        }

        return $condition->user_id == user_id() && $condition->user_type == user_type();
    }

    /**
     * Determine if the given user can create a condition.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.condition.create');
    }

    /**
     * Determine if the given user can update the given condition.
     *
     * @param UserPolicyInterface $authUser
     * @param Condition $condition
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Condition $condition)
    {
        if ($authUser->canDo('asset.condition.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $condition->user_id == user_id() && $condition->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given condition.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Condition $condition)
    {
        return $condition->user_id == user_id() && $condition->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given condition.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Condition $condition)
    {
        if ($authUser->canDo('asset.condition.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given condition.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Condition $condition)
    {
        if ($authUser->canDo('asset.condition.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
