<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\Consequence;

class ConsequencePolicy
{


    /**
     * Determine if the given user can view the consequence.
     *
     * @param UserPolicyInterface $authUser
     * @param Consequence $consequence
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Consequence $consequence)
    {
        if ($authUser->canDo('asset.consequence.view') && $authUser->isAdmin()) {
            return true;
        }

        return $consequence->user_id == user_id() && $consequence->user_type == user_type();
    }

    /**
     * Determine if the given user can create a consequence.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.consequence.create');
    }

    /**
     * Determine if the given user can update the given consequence.
     *
     * @param UserPolicyInterface $authUser
     * @param Consequence $consequence
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Consequence $consequence)
    {
        if ($authUser->canDo('asset.consequence.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $consequence->user_id == user_id() && $consequence->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given consequence.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Consequence $consequence)
    {
        return $consequence->user_id == user_id() && $consequence->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given consequence.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Consequence $consequence)
    {
        if ($authUser->canDo('asset.consequence.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given consequence.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Consequence $consequence)
    {
        if ($authUser->canDo('asset.consequence.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
