<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\Expenditure;

class ExpenditurePolicy
{


    /**
     * Determine if the given user can view the expenditure.
     *
     * @param UserPolicyInterface $authUser
     * @param Expenditure $expenditure
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Expenditure $expenditure)
    {
        if ($authUser->canDo('asset.expenditure.view') && $authUser->isAdmin()) {
            return true;
        }

        return $expenditure->user_id == user_id() && $expenditure->user_type == user_type();
    }

    /**
     * Determine if the given user can create a expenditure.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.expenditure.create');
    }

    /**
     * Determine if the given user can update the given expenditure.
     *
     * @param UserPolicyInterface $authUser
     * @param Expenditure $expenditure
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Expenditure $expenditure)
    {
        if ($authUser->canDo('asset.expenditure.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $expenditure->user_id == user_id() && $expenditure->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given expenditure.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Expenditure $expenditure)
    {
        return $expenditure->user_id == user_id() && $expenditure->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given expenditure.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Expenditure $expenditure)
    {
        if ($authUser->canDo('asset.expenditure.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given expenditure.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Expenditure $expenditure)
    {
        if ($authUser->canDo('asset.expenditure.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
