<?php

namespace Assetise\Asset\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\Asset\Models\Lcc;

class LccPolicy
{


    /**
     * Determine if the given user can view the lcc.
     *
     * @param UserPolicyInterface $authUser
     * @param Lcc $lcc
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Lcc $lcc)
    {
        if ($authUser->canDo('asset.lcc.view') && $authUser->isAdmin()) {
            return true;
        }

        return $lcc->user_id == user_id() && $lcc->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lcc.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('asset.lcc.create');
    }

    /**
     * Determine if the given user can update the given lcc.
     *
     * @param UserPolicyInterface $authUser
     * @param Lcc $lcc
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Lcc $lcc)
    {
        if ($authUser->canDo('asset.lcc.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $lcc->user_id == user_id() && $lcc->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lcc.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Lcc $lcc)
    {
        return $lcc->user_id == user_id() && $lcc->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lcc.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Lcc $lcc)
    {
        if ($authUser->canDo('asset.lcc.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lcc.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Lcc $lcc)
    {
        if ($authUser->canDo('asset.lcc.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
