<?php

namespace Assetise\Asset\Providers;

use Illuminate\Support\ServiceProvider;
use Assetise\Asset\Assets;

class AssetServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'asset');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'asset');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Assetise\Asset\Providers\AuthServiceProvider::class);
        $this->app->register(\Assetise\Asset\Providers\RouteServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('assetise.asset', function($app)
        {
            return $this->app->make(Asset::class);
        });
    }

    /**
     * Merges user's and asset's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'assetise.asset'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/asset.php', 'assetise.asset.asset'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/inspection.php', 'assetise.asset.inspection'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/asset_type.php', 'assetise.asset.asset_type'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/proposal.php', 'assetise.asset.proposal'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/expenditure.php', 'assetise.asset.expenditure'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/approved_jobs.php', 'assetise.asset.approved_jobs'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/asset_level.php', 'assetise.asset.asset_level'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/asset_location.php', 'assetise.asset.asset_location'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/condition.php', 'assetise.asset.condition'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/consequence.php', 'assetise.asset.consequence'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/asset_classification.php', 'assetise.asset.asset_classification'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/lcc.php', 'assetise.asset.lcc'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/condition.php', 'assetise.asset.condition'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/consequence.php', 'assetise.asset.consequence'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['assetise.asset'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('assetise/asset')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/asset')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/asset')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
