<?php

namespace Assetise\Asset\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Assetise\Asset\Models\Asset;
use Assetise\Asset\Models\Inspection;
use Assetise\Asset\Models\AssetType;
use Assetise\Asset\Models\Proposal;
use Assetise\Asset\Models\Expenditure;
use Assetise\Asset\Models\ApprovedJobs;
use Assetise\Asset\Models\AssetLevel;
use Assetise\Asset\Models\AssetLocation;
use Assetise\Asset\Models\Condition;
use Assetise\Asset\Models\Consequence;
use Assetise\Asset\Models\AssetClassification;
use Assetise\Asset\Models\Lcc;
use Assetise\Asset\Models\Condition;
use Assetise\Asset\Models\Consequence;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Assetise\Asset\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/asset/asset/*')) {
            Route::bind('asset', function ($asset) {
                return Asset::findorNew($asset);
            });
        }
        if (Request::is('*/asset/inspection/*')) {
            Route::bind('inspection', function ($inspection) {
                return Inspection::findorNew($inspection);
            });
        }
        if (Request::is('*/asset/asset_type/*')) {
            Route::bind('asset_type', function ($asset_type) {
                return AssetType::findorNew($asset_type);
            });
        }
        if (Request::is('*/asset/proposal/*')) {
            Route::bind('proposal', function ($proposal) {
                return Proposal::findorNew($proposal);
            });
        }
        if (Request::is('*/asset/expenditure/*')) {
            Route::bind('expenditure', function ($expenditure) {
                return Expenditure::findorNew($expenditure);
            });
        }
        if (Request::is('*/asset/approved_jobs/*')) {
            Route::bind('approved_jobs', function ($approved_jobs) {
                return ApprovedJobs::findorNew($approved_jobs);
            });
        }
        if (Request::is('*/asset/asset_level/*')) {
            Route::bind('asset_level', function ($asset_level) {
                return AssetLevel::findorNew($asset_level);
            });
        }
        if (Request::is('*/asset/asset_location/*')) {
            Route::bind('asset_location', function ($asset_location) {
                return AssetLocation::findorNew($asset_location);
            });
        }
        if (Request::is('*/asset/condition/*')) {
            Route::bind('condition', function ($condition) {
                return Condition::findorNew($condition);
            });
        }
        if (Request::is('*/asset/consequence/*')) {
            Route::bind('consequence', function ($consequence) {
                return Consequence::findorNew($consequence);
            });
        }
        if (Request::is('*/asset/asset_classification/*')) {
            Route::bind('asset_classification', function ($asset_classification) {
                return AssetClassification::findorNew($asset_classification);
            });
        }
        if (Request::is('*/asset/lcc/*')) {
            Route::bind('lcc', function ($lcc) {
                return Lcc::findorNew($lcc);
            });
        }
        if (Request::is('*/asset/condition/*')) {
            Route::bind('condition', function ($condition) {
                return Condition::findorNew($condition);
            });
        }
        if (Request::is('*/asset/consequence/*')) {
            Route::bind('consequence', function ($consequence) {
                return Consequence::findorNew($consequence);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
